﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.IO;
using System.Drawing.Drawing2D;
using System.Drawing.Imaging;

namespace howto_resize_pics
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // Let the user browse for the directory.
        private void btnPickDirectory_Click(object sender, EventArgs e)
        {
            try
            {
                fbdDirectory.SelectedPath = txtDirectory.Text;
            }
            catch
            {
            }

            if (fbdDirectory.ShowDialog() == DialogResult.OK)
            {
                txtDirectory.Text = fbdDirectory.SelectedPath;
            }
        }

        // Process the files in the selected directory.
        private void btnGo_Click(object sender, EventArgs e)
        {
            float scale = float.Parse(txtScale.Text);
            if (scale == 0)
            {
                MessageBox.Show("Scale must not be zero.",
                    "Invalid Scale", MessageBoxButtons.OK,
                    MessageBoxIcon.Error);
                return;
            }
            Cursor = Cursors.WaitCursor;
            Refresh();

            DirectoryInfo dir_info = new DirectoryInfo(txtDirectory.Text);
            foreach (FileInfo file_info in dir_info.GetFiles())
            {
                try
                {
                    string ext = file_info.Extension.ToLower();
                    if ((ext == ".bmp") || (ext == ".gif") ||
                        (ext == ".jpg") || (ext == ".jpeg") ||
                        (ext == ".png"))
                    {
                        using (Bitmap bm = new Bitmap(file_info.FullName))
                        {
                            picWorking.Image = bm;
                            Text = "howto_2005_resize_pics - " +
                                file_info.Name;
                            Application.DoEvents();

                            Rectangle from_rect =
                                new Rectangle(0, 0, bm.Width, bm.Height);

                            int wid2 = (int)Math.Round(scale * bm.Width);
                            int hgt2 = (int)Math.Round(scale * bm.Height);
                            using (Bitmap bm2 = new Bitmap(wid2, hgt2))
                            {
                                Rectangle dest_rect = new Rectangle(0, 0, wid2, hgt2);
                                using (Graphics gr = Graphics.FromImage(bm2))
                                {
                                    gr.InterpolationMode =
                                        InterpolationMode.HighQualityBicubic;
                                    gr.DrawImage(bm, dest_rect, from_rect,
                                        GraphicsUnit.Pixel);
                                }

                                string new_name = file_info.FullName;
                                new_name = new_name.Substring(0,
                                    new_name.Length - ext.Length);
                                new_name += "_s" + ext;
                                SaveImage(bm2, new_name);

                                picWorking.Image = null;
                            }
                        }
                    } // if it's a graphic extension
                }
                catch (Exception ex)
                {
                    MessageBox.Show("Error processing file '" +
                        file_info.Name + "'\n" + ex.Message,
                        "Error",
                        MessageBoxButtons.OK,
                        MessageBoxIcon.Error);
                }
            } // foreach file_info

            Text = "howto_resize_pics";
            Cursor = Cursors.Default;
        }

        // Restore parameters.
        private void Form1_Load(object sender, EventArgs e)
        {
            SetBounds(
                Properties.Settings.Default.Left,
                Properties.Settings.Default.Top,
                Properties.Settings.Default.Width,
                Properties.Settings.Default.Height);

            txtDirectory.Text = Properties.Settings.Default.Directory;
            if (txtDirectory.Text.Length == 0) txtDirectory.Text = Application.StartupPath;
            txtScale.Text = Properties.Settings.Default.Scale;
        }

        // Save parameters.
        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            Properties.Settings.Default.Left = Left;
            Properties.Settings.Default.Top = Top;
            Properties.Settings.Default.Width = Width;
            Properties.Settings.Default.Height = Height;

            Properties.Settings.Default.Directory = txtDirectory.Text;
            Properties.Settings.Default.Scale = txtScale.Text;

            Properties.Settings.Default.Save();
        }

        // Save the file with the appropriate format.
        public void SaveImage(Image image, string filename)
        {
            string extension = Path.GetExtension(filename);
            switch (extension.ToLower())
            {
                case ".bmp":
                    image.Save(filename, ImageFormat.Bmp);
                    break;
                case ".exif":
                    image.Save(filename, ImageFormat.Exif);
                    break;
                case ".gif":
                    image.Save(filename, ImageFormat.Gif);
                    break;
                case ".jpg":
                case ".jpeg":
                    image.Save(filename, ImageFormat.Jpeg);
                    break;
                case ".png":
                    image.Save(filename, ImageFormat.Png);
                    break;
                case ".tif":
                case ".tiff":
                    image.Save(filename, ImageFormat.Tiff);
                    break;
                default:
                    throw new NotSupportedException(
                        "Unknown file extension " + extension);
            }
        }
    }
}
